@@ -1,3 +1,5 @@
+defaultExogenous <- TRUE
+
 makeFitFunction <- function(fitfun)
 {
   if(fitfun == "WLS")        mxFitFunctionWLS(allContinuousMethod= "marginals")
@@ -278,6 +280,7 @@ setupExogenousCovariates <- function(model, covariates, itemNames)
 # export? TODO
 setupData <- function(phenoData, gxe, customMinMAF, minMAF, fitfun)
 {
+  phenoData <- as.data.frame(phenoData)
   if (customMinMAF && fitfun != "WLS") warning("minMAF is ignored when fitfun != 'WLS'")
   minVar <- calcMinVar(minMAF)
   result <- list()
@@ -313,8 +316,7 @@ endogenousSNPpath <- function(depVar)
 		      mxPath(from = "snp", arrows=2, values=1, labels = paste("snp", "res", sep = "_")))
 }
 
-# endogenous covariates handled here
-setupPaths <- function(phenoData, covariates, depVar)
+endogenousCovariatePaths <- function(phenoData, covariates, depVar)
 {
 	paths <- list()
 
@@ -336,24 +338,33 @@ setupPaths <- function(phenoData, covariates, depVar)
 	paths
 }
 
+#' @importFrom OpenMx omxQuotes
 postprocessModel <- function(model, indicators, exogenous)
 {
 	model <- setupThresholds(model)
 
+  isInt <- sapply(model$data$observed, function(x) typeof(x) == 'integer')
+
 	if (length(exogenous) == 0 &&
 		    is.na(model$expectation$thresholds) &&
 		    is(model$fitfunction, 'MxFitFunctionWLS')) {
+    if (any(isInt)) {
+      warning(paste("Cumulants method prevented by integer observed columns:",
+                    omxQuotes(names(isInt)[isInt]),
+                    "; Remove these columns from your observed data for",
+                    "improved estimation accuracy"))
+    } else {
+      # cumulants is substantially more precise than marginals
+      model$fitfunction$continuousType <- 'cumulants'
 
-		# cumulants is substantially more precise than marginals
-		model$fitfunction$continuousType <- 'cumulants'
-
-		# discard model means
-		if (is(model$expectation, "MxExpectationRAM")) {
-			model$expectation$M <- as.character(NA)
-			model <- mxModel(model, 'M', remove = TRUE)
-		} else {
-      stop("Only RAM models are supported")
-		}
+      # discard model means
+      if (is(model$expectation, "MxExpectationRAM")) {
+        model$expectation$M <- as.character(NA)
+        model <- mxModel(model, 'M', remove = TRUE)
+      } else {
+        stop("Only RAM models are supported")
+      }
+    }
 	} else {
 		model <- setupExogenousCovariates(model, exogenous, indicators)
 	}
@@ -420,7 +431,7 @@ buildItem <- function(phenoData, depVar, covariates=NULL, ..., fitfun = c("WLS",
 	  latents <- c("snp", covariates)
   }
   
-  paths <- setupPaths(phenoData, endoCovariates, depVar)
+  paths <- endogenousCovariatePaths(phenoData, endoCovariates, depVar)
   if (!exogenous) paths <- c(paths, endogenousSNPpath(depVar))
   paths <- c(paths,
 	     mxPath(from = c(depVar), arrows=2, values=1, free = !fac, labels = paste(c(depVar), "res", sep = "_")),
@@ -479,7 +490,7 @@ buildOneFac <- function(phenoData, itemNames, covariates=NULL, ..., fitfun = c("
   fitfun <- match.arg(fitfun)
 
   fac <- sapply(phenoData[,itemNames,drop=FALSE], is.factor)
-  if (is.na(exogenous)) exogenous <- FALSE
+  if (is.na(exogenous)) exogenous <- defaultExogenous
 
   phenoData <- addPlaceholderSNP(phenoData)
   manifest <- c("snp", itemNames)
@@ -494,7 +505,7 @@ buildOneFac <- function(phenoData, itemNames, covariates=NULL, ..., fitfun = c("
 	  manifest <- c(manifest, covariates)
 	  endoCovariates <- covariates
   }
-  paths <- c(endogenousSNPpath(depVar), setupPaths(phenoData, endoCovariates, depVar))
+  paths <- c(endogenousSNPpath(depVar), endogenousCovariatePaths(phenoData, endoCovariates, depVar))
   paths <- c(paths,
 	     mxPath(from=depVar, to=itemNames,values=1, free = T,
 		    labels = paste("lambda", itemNames, sep = "_")  ),
@@ -552,7 +563,7 @@ buildOneFacRes <- function(phenoData, itemNames, factor = F, res = itemNames, co
   fitfun <- match.arg(fitfun)
   
   fac <- sapply(phenoData[,itemNames,drop=FALSE], is.factor)
-  if (is.na(exogenous)) exogenous <- FALSE
+  if (is.na(exogenous)) exogenous <- defaultExogenous
 
   phenoData <- addPlaceholderSNP(phenoData)
   manifest <- c("snp", itemNames)
@@ -569,7 +580,7 @@ buildOneFacRes <- function(phenoData, itemNames, factor = F, res = itemNames, co
 	  endoCovariates <- covariates
   }
 
-  paths <- c(endogenousSNPpath(depVar), setupPaths(phenoData, endoCovariates, depVar))
+  paths <- c(endogenousSNPpath(depVar), endogenousCovariatePaths(phenoData, endoCovariates, 'F'))
   paths <- c(paths,
 	     mxPath(from="F", to=itemNames,values=1, free = T,
 		    labels = paste("lambda", itemNames, sep = "_")  ),
@@ -626,7 +637,7 @@ buildTwoFac <- function(phenoData, F1itemNames, F2itemNames, covariates = NULL,
   itemNames <- union(F1itemNames, F2itemNames)
 
   fac <- sapply(phenoData[,itemNames,drop=FALSE], is.factor)
-  if (is.na(exogenous)) exogenous <- FALSE
+  if (is.na(exogenous)) exogenous <- defaultExogenous
 
   phenoData <- addPlaceholderSNP(phenoData)
   manifest <- c("snp", itemNames)
@@ -642,7 +653,7 @@ buildTwoFac <- function(phenoData, F1itemNames, F2itemNames, covariates = NULL,
 	  endoCovariates <- covariates
   }
 
-  paths <- c(endogenousSNPpath(depVar), setupPaths(phenoData, endoCovariates, depVar))
+  paths <- c(endogenousSNPpath(depVar), endogenousCovariatePaths(phenoData, endoCovariates, depVar))
   paths <- c(paths,
 	     mxPath(from="F1", to=F1itemNames,values=1, labels = paste("F1_lambda", F1itemNames, sep = "_")  ),
 	     mxPath(from="F2", to=F2itemNames,values=1, labels = paste("F2_lambda", F2itemNames, sep = "_")  ),
